跳到主要内容

Rational

搜索

结构体 Rational 

源代码
pub struct Rational(pub i32, pub i32);

Tuple Fields

0: i321: i32

实现

源代码

impl Rational

源代码

pub fn new(numerator: i32, denominator: i32) -> Self

源代码

pub fn numerator(&self) -> i32

源代码

pub fn denominator(&self) -> i32

源代码

pub fn reduce(&self) -> Rational

源代码

pub fn reduce_with_limit(&self, max: i32) -> Result<Rational, Rational>

源代码

pub fn invert(&self) -> Rational

trait 实现

源代码

impl Add for Rational

源代码

type Output = Rational

The resulting type after applying the + operator.
源代码

fn add(self, other: Rational) -> Rational

Performs the + operation. 阅读更多
源代码

impl Clone for Rational

源代码

fn clone(&self) -> Rational

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for Rational

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Display for Rational

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Div for Rational

源代码

type Output = Rational

The resulting type after applying the / operator.
源代码

fn div(self, other: Rational) -> Rational

Performs the / operation. 阅读更多
源代码

impl From<(i32, i32)> for Rational

源代码

fn from((num, den): (i32, i32)) -> Rational

Converts to this type from the input type.
源代码

impl From<AVRational> for Rational

源代码

fn from(value: AVRational) -> Rational

Converts to this type from the input type.
源代码

impl From<Rational> for AVRational

源代码

fn from(value: Rational) -> AVRational

Converts to this type from the input type.
源代码

impl From<Rational> for f64

源代码

fn from(value: Rational) -> f64

Converts to this type from the input type.
源代码

impl From<Rational> for u32

源代码

fn from(value: Rational) -> u32

Converts to this type from the input type.
源代码

impl From<f64> for Rational

源代码

fn from(value: f64) -> Rational

Converts to this type from the input type.
源代码

impl Mul for Rational

源代码

type Output = Rational

The resulting type after applying the * operator.
源代码

fn mul(self, other: Rational) -> Rational

Performs the * operation. 阅读更多
源代码

impl PartialEq for Rational

源代码

fn eq(&self, other: &Rational) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl PartialOrd for Rational

源代码

fn partial_cmp(&self, other: &Self) -> Option<Ordering>

如果存在的话,该方法返回 selfother 之间的顺序。 阅读更多
1.0.0 · 源代码

fn lt(&self, other: &Rhs) -> bool

测试小于(对于 selfother),由 < 运算符使用。 阅读更多
1.0.0 · 源代码

fn le(&self, other: &Rhs) -> bool

Tests less than or equal to (for self and other) and is used by the <= operator. 阅读更多
1.0.0 · 源代码

fn gt(&self, other: &Rhs) -> bool

测试大于(对于 selfother),由 > 运算符使用。 阅读更多
1.0.0 · 源代码

fn ge(&self, other: &Rhs) -> bool

测试大于等于(对于 selfother),由 >= 运算符使用。 阅读更多
源代码

impl Sub for Rational

源代码

type Output = Rational

The resulting type after applying the - operator.
源代码

fn sub(self, other: Rational) -> Rational

Performs the - operation. 阅读更多
源代码

impl Copy for Rational

源代码

impl Eq for Rational

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T> ToString for T
where T: Display + ?Sized,

源代码

fn to_string(&self) -> String

Converts the given value to a String. 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。